#========================================================================================
# package      DE_EPAGES::DHLIntraship::t::DeveloperAuthentication
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test of DeveloperAuthentication
#========================================================================================
package DE_EPAGES::DHLIntraship::t::DeveloperAuthentication;

use strict;
use DE_EPAGES::DHLIntraship::API::DeveloperAuthentication;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use Test::MockObject::Extends;
use DE_EPAGES::Core::API::Error qw (ExistsError GetError );
use Test::More;

sub Main {
    testLiveAccountDeveloperAuthentication();
    testTestAccountDeveloperAuthentication();
    testBuildUndefDeveloperAuthentication();
    done_testing();
}

sub testLiveAccountDeveloperAuthentication {
    my $subTestName = (caller(0))[3];
    my $DeveloperAuthentication = DE_EPAGES::DHLIntraship::API::DeveloperAuthentication->new();
    my $MockedDeveloperAuthentication = Test::MockObject::Extends->new($DeveloperAuthentication);
    $MockedDeveloperAuthentication->mock('_GetAuthorKeys', sub { return _createConfigInfo(); });

    is($MockedDeveloperAuthentication->getUserName(), 'LiveUsername', "$subTestName - test getUserName for live account");
    is($MockedDeveloperAuthentication->getPassWord(), 'LivePassword', "$subTestName - test getPassword for live account");
    is($MockedDeveloperAuthentication->getRealm(), 'CIG Production Services', "$subTestName - test getRealm for live account");
}

sub testTestAccountDeveloperAuthentication {
    my $subTestName = (caller(0))[3];

    my $IsTestRequest = 1;
    my $DeveloperAuthentication = DE_EPAGES::DHLIntraship::API::DeveloperAuthentication->new($IsTestRequest);
    my $MockedDeveloperAuthentication = Test::MockObject::Extends->new($DeveloperAuthentication);
    $MockedDeveloperAuthentication->mock('_GetAuthorKeys', sub { return _createConfigInfo(); });

    is($MockedDeveloperAuthentication->getUserName(), 'TestUsername', "$subTestName - test getUserName for test account");
    is($MockedDeveloperAuthentication->getPassWord(), 'TestPassword', "$subTestName - test getPassword for test account");
    is($MockedDeveloperAuthentication->getRealm(), 'CIG Sandbox Services', "$subTestName - test getRealm for test account");
}

sub testBuildUndefDeveloperAuthentication {
    my $subTestName = (caller(0))[3];
    my ($IsTest) = @_;

    my $DeveloperAuthentication = DE_EPAGES::DHLIntraship::API::DeveloperAuthentication->new($IsTest);
    my $MockedDeveloperAuthentication = Test::MockObject::Extends->new($DeveloperAuthentication);

    $MockedDeveloperAuthentication->mock('_GetAuthorKeys',
        sub {
               return undef;
        }
    );
    eval {
        $MockedDeveloperAuthentication->getUserName();
    };
    if (ExistsError()) {
        my $Error = GetError();
        is($Error->code(), 'Undefined Developer Authentication (No keys in epages.conf)', "$subTestName - error handling in the case of undef developer Authentication in epages.conf");
    }
}

sub _createConfigInfo {
    my $hConfigInfo = {
        'UserNameTest' => 'TestUsername',
        'UserNameLive' => 'LiveUsername',
        'PasswordTest' => 'TestPassword',
        'PasswordLive' => 'LivePassword'
    };
    return $hConfigInfo;
}
RunScript( Sub => \&Main );