package DE_EPAGES::Object::t::Country;
use base DE_EPAGES::Database::API::Test;
use strict;
use Test::More tests => 13;
use DE_EPAGES::Object::API::Factory qw( LoadClassByAlias );

use constant COUNTRYID_UNKNOWN => 997;
use constant COUNTRYID_KLINGON => 998;
use constant COUNTRY_PACKAGE => 'DE_EPAGES::Object::API::Object::Country';

sub test {

    my $ClassCountry = LoadClassByAlias( 'Country' );
    my $Country = $ClassCountry->insertObject({
        CountryID => COUNTRYID_KLINGON,
        Code2 => 'KL',
        Code3 => 'KLN',
        English => 'Klingon',
        French => 'Klingon',
        Native => 'Klingon',
    });

    is( $Country->get('CountryID'), COUNTRYID_KLINGON, 'get CountryID' );
    is( $Country->get('Code2'), 'KL', 'get Code2' );
    is( $Country->get('Code3'), 'KLN', 'get Code3' );
    is( $Country->get('English'), 'Klingon', 'get English' );
    is( $Country->get('French'), 'Klingon', 'get French' );
    is( $Country->get('Native'), 'Klingon', 'get Native' );
    is( $Country->get('IsEU'), 0, 'get IsEU' );
    is( $Country->get('SubdivsMandatory'), 0, 'get SubdivsMandatory' );

    my $CountryID = COUNTRY_PACKAGE->findXML( undef, undef, $ClassCountry, {
        CountryID => COUNTRYID_KLINGON, Code2 => 'XX', Code3 => 'XXX',
    });
    is( $CountryID, COUNTRYID_KLINGON, 'findXML: search for CountryID first' );

    $CountryID = COUNTRY_PACKAGE->findXML( undef, undef, $ClassCountry, {
        CountryID => COUNTRYID_UNKNOWN, Code2 => 'KL', Code3 => 'KLN',
    });
    is( $CountryID, undef, 'findXML: CountryID not found' );

    $CountryID = COUNTRY_PACKAGE->findXML( undef, undef, $ClassCountry, {
        Code2 => 'XX', Code3 => 'KLN',
    });
    is( $CountryID, COUNTRYID_KLINGON, 'findXML: search Code3 before Code2' );

    $CountryID = COUNTRY_PACKAGE->findXML( undef, undef, $ClassCountry, {
        Code2 => 'KL', Code3 => 'XXX',
    });
    is( $CountryID, undef, 'findXML: Code3 not found' );

    $CountryID = COUNTRY_PACKAGE->findXML( undef, undef, $ClassCountry, {
        Code2 => 'KL',
    });
    is( $CountryID, COUNTRYID_KLINGON, 'findXML: find by Code2' );

}

sub cleanup {

    my $ClassCountry = LoadClassByAlias( 'Country' );
    $ClassCountry->loadObject(COUNTRYID_KLINGON)->delete if $ClassCountry->existsObject(COUNTRYID_KLINGON);
}

__PACKAGE__->runScript;
