#!perl -w
package DE_EPAGES::Object::t::XMLCompare;
use base DE_EPAGES::Core::API::Test;

use strict;
use Test::Simple tests => 30;
use DE_EPAGES::Core::API::File qw( RunOnDirectory );
use DE_EPAGES::Object::API::XMLCompare qw ( CompareXML );

sub test {
    RunOnDirectory('XMLCompare', sub { Main() });
}

sub Main {

    ok(!CompareXML('reference.xml','reference(missingShippingAddress).xml'), "find missing shipping address 1st");
    ok(CompareXML('reference(missingShippingAddress).xml','reference.xml', {'printmessage' => '1'}), "ignore extra shipping address");

    ok(!CompareXML('reference.xml','reference(missingShop).xml'), "find missing shop");
    ok(CompareXML('reference(missingShop).xml','reference.xml', {'printmessage' => '1'}), "ignore extra shop");

    ok(CompareXML('reference(without_delete_in_tags).xml','reference.xml', {'printmessage' => '1'}), "ignore 'delete' in tags");
    ok(CompareXML('reference.xml','reference(without_delete_in_tags).xml', {'printmessage' => '1'}), "ignore 'delete' in tags");

    ok(CompareXML('reference(with_reference_in_tags).xml','reference.xml', {'printmessage' => '1'}), "ignore 'reference' in tags");
    ok(CompareXML('reference.xml','reference(with_reference_in_tags).xml', {'printmessage' => '1'}), "ignore 'reference' in tags");

    ok(CompareXML('reference(without_delete_in_tags).xml','reference(with_reference_in_tags).xml', {'printmessage' => '1'}), "ignore 'delete' and 'reference' in tags");
    ok(CompareXML('reference(with_reference_in_tags).xml','reference(without_delete_in_tags).xml', {'printmessage' => '1'}), "ignore 'reference' and 'delete' in tags");

    ok(CompareXML('reference(splitting-hierarchy).xml','reference.xml', {'printmessage' => '1'}), "ignore splitting hierarchy");
    ok(CompareXML('reference.xml','reference(splitting-hierarchy).xml', {'printmessage' => '1'}), "ignore splitting hierarchy");

    ok(!CompareXML('reference(splitting-hierarchy-extra-customer).xml','reference.xml'), "ignore splitting hierarchy and find missing customer");
    ok(CompareXML('reference.xml','reference(splitting-hierarchy-extra-customer).xml', {'printmessage' => '1'}), "ignore splitting hierarchy with extra customer");

    ok(!CompareXML('reference(changed_class).xml','reference.xml'), "find changed Class");

    ok(CompareXML('reference(attribute-value-in-tag).xml','reference(attribute-value-in-hierarchy).xml', {'printmessage' => '1'}), "attribute values similar");

    ok(CompareXML('reference(2).xml','control(2).xml', {'printmessage' => '1'}), "attribute values similar");

    ok(CompareXML('reference(3).xml','control(3).xml', {'printmessage' => '1'}), "relative path correct created");

    ok(CompareXML('reference(4).xml','control(4).xml', {'printmessage' => '1'}), "find localized attributes");

    ok(CompareXML('reference(5).xml','control(5).xml', {'printmessage' => '1'}), "identified taxrate in two different ways");

    #ok(CompareXML('reference(6).xml','control(6).xml', 1), "collect attributes from export-level=2");

    ok(CompareXML('reference(7).xml','control(7).xml', {'printmessage' => '1'}), "multi cartridge tags 1st");
    ok(CompareXML('control(7).xml', 'reference(7).xml', {'printmessage' => '1'}), "multi cartridge tags 2nd");

    ok(CompareXML('reference(8).xml','control(8).xml', {'printmessage' => '1'}), "apostroph in attribute text 1st");
    ok(CompareXML('control(8).xml', 'reference(8).xml', {'printmessage' => '1'}), "apostroph in attribute text 2nd");

    ok(CompareXML('reference(9).xml','control(9).xml', {'printmessage' => '1'}), "cartridge tag 1st");
    ok(CompareXML('control(9).xml', 'reference(9).xml', {'printmessage' => '1'}), "cartridge tag 2nd");

    ok(CompareXML('reference(10).xml','control(10).xml', {'printmessage' => '1'}), "object adressed by alias and path 1st");
    ok(CompareXML('control(10).xml', 'reference(10).xml', {'printmessage' => '1'}), "object adressed by alias and path 2nd");

    ok(CompareXML('reference(11).xml','control(11).xml', {'checkdelete' => '1', 'checkreference' => '1', 'printmessage' => '1'}), "right delete/reference 1st");
    ok(CompareXML('control(11).xml', 'reference(11).xml', {'checkdelete' => '1', 'checkreference' => '1', 'printmessage' => '1'}), "right delete/reference 2nd");
}

__PACKAGE__->runScript;
