package DE_EPAGES::Shipping::t::ShippingMethodCollectionResourceIntegration;
use base DE_EPAGES::Shop::API::Test;

use strict;
use Test::More tests => 5;

use Data::Dumper;
use HTTP::Status qw( HTTP_BAD_REQUEST );
use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw( ImportObjects );
use DE_EPAGES::WebInterface::API::FakeRequest;
use DE_EPAGES::WebService::API::Codec::JSON;
use DE_EPAGES::WebService::API::JSONRestClient;

my $ShopDomain = 'test-domain';

## no critic qw( ProhibitMagicNumbers );

sub test {
    my $self = shift;

    $self->test_get;
}

sub _basicAuthentication {
    my $self = shift;

    return [ $self->shop->get('SuperMerchant')->alias, 'admin' ];
}

sub _resource {
    my $self = shift;
    my ($ContentType) = @_;

    return DE_EPAGES::WebService::API::JSONRestClient->new("http://$ShopDomain/api/shipping-methods", {
        UserAgent => DE_EPAGES::WebInterface::API::FakeRequest->new,
        BasicAuthentication => $self->_basicAuthentication,
        Codec => DE_EPAGES::WebService::API::Codec::JSON->new(
            ContentType => $ContentType
        ),
    });
}

sub _TestHttpError(&$$) {
    my ( $Sub, $ExpectedStatus, $Message ) = @_;

    eval { $Sub->() };
    ok ExistsError(), "$Message: error expected";
    my $Error = GetError();
    is $Error->code, 'HttpError', "$Message: error code";
    is $Error->vars->{'Code'}, $ExpectedStatus, "$Message: HTTP status code=$ExpectedStatus"
}

sub test_get {
    my $self = shift;

    my $Resource = $self->_resource('application/json');
    my $LocaleID = 'en_GB';

    my $ahData = $Resource->get("?locale=$LocaleID");

    # details are tested by ShippingMethodResource.t
    is( scalar @$ahData, 2, 'GET all shipping-methods' ) or diag Dumper($ahData);
    is( scalar keys %{$ahData->[0]}, 4, 'number of keys in JSON response' ) or diag Dumper($ahData);

    _TestHttpError sub { $Resource->get('?locale=ru_RU') },
        HTTP_BAD_REQUEST,
        'invalid locale - Bad Request';
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';

    note 'importing import.xml';
    ImportObjects('import.xml', $self->shop->parent->pathString);

    $self->shop->set({DomainName => $ShopDomain});
}

__PACKAGE__->runScript;
