package DE_EPAGES::Shipping::t::ShippingMethodResourceIntegration;
use base DE_EPAGES::Shop::API::Test;

use strict;
use Test::More tests => 7;

use Data::Dumper;
use HTTP::Status qw( HTTP_BAD_REQUEST HTTP_NOT_FOUND );
use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw( ImportObjects );
use DE_EPAGES::WebInterface::API::FakeRequest;
use DE_EPAGES::WebService::API::Codec::JSON;
use DE_EPAGES::WebService::API::JSONRestClient;

my $ShopDomain = 'test-domain';

## no critic qw( ProhibitMagicNumbers );

sub test {
    my $self = shift;

    $self->test_get;
}

sub _basicAuthentication {
    my $self = shift;

    return [ $self->shop->get('SuperMerchant')->alias, 'admin' ];
}

sub _resource {
    my $self = shift;
    my ($ContentType) = @_;

    return DE_EPAGES::WebService::API::JSONRestClient->new("http://$ShopDomain/api/shipping-methods", {
        UserAgent => DE_EPAGES::WebInterface::API::FakeRequest->new,
        BasicAuthentication => $self->_basicAuthentication,
        Codec => DE_EPAGES::WebService::API::Codec::JSON->new(
            ContentType => $ContentType
        ),
    });
}

sub _shippingMethodGUID {
    my $self = shift;
    my ($Alias) = @_;

    return $self->shop->child('ShippingMethods')->child($Alias)->guid;
}

sub _TestHttpError(&$$) {
    my ( $Sub, $ExpectedStatus, $Message ) = @_;

    eval { $Sub->() };
    ok ExistsError(), "$Message: error expected";
    my $Error = GetError();
    is $Error->code, 'HttpError', "$Message: error code";
    is $Error->vars->{'Code'}, $ExpectedStatus, "$Message: HTTP status code=$ExpectedStatus"
}

sub test_get {
    my $self = shift;

    my $Resource = $self->_resource('application/json');
    my $LocaleID = 'en_GB';
    my $ShippingMethodGUID = $self->_shippingMethodGUID('TestShipping1');

    my $hData = $Resource->get( $ShippingMethodGUID ."?locale=$LocaleID" );

    # details are tested by ShippingMethodResource.t
    is( scalar keys %$hData, 4, 'GET TestShipping1' ) or diag Dumper($hData);

    _TestHttpError sub { $Resource->get( 'UnknownGUID?locale=en_GB&currency=EUR' ) },
        HTTP_NOT_FOUND,
        'invalid guid - Not Found';

    _TestHttpError sub { $Resource->get( $ShippingMethodGUID .'?locale=ru_RU' ) },
        HTTP_BAD_REQUEST,
        'invalid locale - Bad Request';
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    die 'Shop alias is not TestShop' unless $self->shop->alias eq 'TestShop';

    note 'importing import.xml';
    ImportObjects('import.xml', $self->shop->parent->pathString);

    $self->shop->set({DomainName => $ShopDomain});
}

__PACKAGE__->runScript;
